@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import List, Optional
 
 import requests as requests
@@ -6,7 +8,7 @@ from ..exceptions.exceptions import MissingAPIKeyException
 
 
 class EmbeddingBlock:
-    def embed_text(self, text: str) -> List[int]:
+    def embed_text(self, text: str) -> list[int]:
         pass
 
 
@@ -20,7 +22,7 @@ def check_key_decorator(func):
 
 
 class OpenAIEmbeddingBlock(EmbeddingBlock):
-    open_ai_key: Optional[str] = None
+    open_ai_key: str | None = None
 
     def __init__(self, open_ai_key: str, use_helicone: bool = False) -> None:
         self.open_ai_key = open_ai_key
@@ -30,7 +32,7 @@ class OpenAIEmbeddingBlock(EmbeddingBlock):
             self.base_url = "https://api.openai.com/v1"
 
     @check_key_decorator
-    def embed_text(self, text: str) -> List[int]:
+    def embed_text(self, text: str) -> list[int]:
         headers = {
             "Content-Type": "application/json",
             "Authorization": f"Bearer {self.open_ai_key}",
